Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(796)

Unified Diff: chrome/browser/extensions/image_loader_factory.h

Issue 11027044: Add a class to replace ImageLoadingTracker with a nicer API. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix include order Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/image_loader_factory.h
diff --git a/chrome/browser/extensions/app_restore_service_factory.h b/chrome/browser/extensions/image_loader_factory.h
similarity index 51%
copy from chrome/browser/extensions/app_restore_service_factory.h
copy to chrome/browser/extensions/image_loader_factory.h
index 519e23425c618d55791748bced7c905e076a9f0a..767316b3e39ee97b817598b97108150af7822398 100644
--- a/chrome/browser/extensions/app_restore_service_factory.h
+++ b/chrome/browser/extensions/image_loader_factory.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_EXTENSIONS_APP_RESTORE_SERVICE_FACTORY_H_
-#define CHROME_BROWSER_EXTENSIONS_APP_RESTORE_SERVICE_FACTORY_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_IMAGE_LOADER_FACTORY_H_
+#define CHROME_BROWSER_EXTENSIONS_IMAGE_LOADER_FACTORY_H_
#include "base/memory/singleton.h"
#include "chrome/browser/profiles/profile_keyed_service_factory.h"
@@ -12,31 +12,32 @@ class Profile;
namespace extensions {
-class AppRestoreService;
+class ImageLoader;
-// Singleton that owns all AppRestoreServices and associates them with
+// Singleton that owns all ImageLoaders and associates them with
// Profiles. Listens for the Profile's destruction notification and cleans up
-// the associated AppRestoreService.
-class AppRestoreServiceFactory : public ProfileKeyedServiceFactory {
+// the associated ImageLoader.
+class ImageLoaderFactory : public ProfileKeyedServiceFactory {
public:
- static AppRestoreService* GetForProfile(Profile* profile);
+ static ImageLoader* GetForProfile(Profile* profile);
static void ResetForProfile(Profile* profile);
- static AppRestoreServiceFactory* GetInstance();
+ static ImageLoaderFactory* GetInstance();
private:
- friend struct DefaultSingletonTraits<AppRestoreServiceFactory>;
+ friend struct DefaultSingletonTraits<ImageLoaderFactory>;
- AppRestoreServiceFactory();
- virtual ~AppRestoreServiceFactory();
+ ImageLoaderFactory();
+ virtual ~ImageLoaderFactory();
// ProfileKeyedServiceFactory:
virtual ProfileKeyedService* BuildServiceInstanceFor(
Profile* profile) const OVERRIDE;
virtual bool ServiceIsCreatedWithProfile() const OVERRIDE;
+ virtual bool ServiceRedirectedInIncognito() const OVERRIDE;
};
} // namespace extensions
-#endif // CHROME_BROWSER_EXTENSIONS_APP_RESTORE_SERVICE_FACTORY_H_
+#endif // CHROME_BROWSER_EXTENSIONS_IMAGE_LOADER_FACTORY_H_

Powered by Google App Engine
This is Rietveld 408576698